"""
Rich-Agents 共享基础设施包
提供统一的LLM适配器、缓存系统、配置管理和工具函数
"""

__version__ = "0.1.0"
__author__ = "Rich-Agents Team"

# 导入主要组件将在后续实现后添加
# from .config.rich_agents_config_manager import RichAgentsConfigManager
# from .llm_adapters.unified_llm_adapter import UnifiedLLMAdapter

__all__ = [
    # "RichAgentsConfigManager",
    # "UnifiedLLMAdapter",
]
